@@ -2,7 +2,7 @@
 
 use strict;
 use warnings;
-our $VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 use VCS::Rcs::Parser;
 
@@ -26,6 +26,7 @@ my $test_dir =  "test_dir/";
 while (my $file = readdir(DIR)) {
 
     next unless $file=~/\w/;
+    next if $file=~/CVS/;
 
     warn "opening file:$file\n";
 
@@ -41,7 +42,7 @@ while (my $file = readdir(DIR)) {
 
     warn "getting revisions of file:$file\n";
 
-    $revs = $rcs->revs(index=>'date');
+    $revs = $rcs->revs(index=>'rev');
 
     for $rev (sort keys %$revs) {
 
